@@ -25,6 +25,25 @@ class TestConnection(unittest.TestCase):
         cursor.execute("MATCH (n:TestCommit) RETURN n.name")
         self.assertEqual(cursor.fetchone(), (1337,))
 
+    def test_read_and_commit(self):
+        # Given
+        cursor = self.conn.cursor()
+        cursor.execute("CREATE (n:TestCommit {name:1337})")
+        cursor.rowcount # Force client to execute
+
+        # When
+        self.conn.commit()
+
+        # Then other cursors should see it
+        cursor = self.conn.cursor()
+        cursor.execute("MATCH (n:TestCommit) RETURN n.name")
+        self.assertEqual(cursor.fetchone(), (1337,))
+
+        # And other connections should see it
+        cursor = neo4j.connect("http://localhost:7474").cursor()
+        cursor.execute("MATCH (n:TestCommit) RETURN n.name")
+        self.assertEqual(cursor.fetchone(), (1337,))
+
     def test_rollback(self):
         # Given
         cursor = self.conn.cursor()
