@@ -1,11 +1,16 @@
-import os, urllib, tarfile
+import os, tarfile
 from subprocess import call
 from paver.easy import *
 from paver.setuputils import setup, find_packages
 
+try:
+    from urllib.request import urlretrieve
+except:
+    from urllib import urlretrieve
+
 setup(
     name='neo4jdb',
-    version='0.0.2',
+    version='0.0.3',
     author='Jacob Hansson',
     author_email='jakewins@gmail.com',
     packages=find_packages(),
@@ -14,7 +19,13 @@ setup(
     install_requires=[],
     url='https://github.com/jakewins/neo4jdb-python',
     description='DB API 2.0 driver for the Neo4j graph database.',
-    long_description=open('README').read(),
+    long_description=open('README.rst').read(),
+    classifiers=[
+      'Programming Language :: Python :: 2.6',
+      'Programming Language :: Python :: 2.7',
+      'Programming Language :: Python :: 3.2',
+      'Programming Language :: Python :: 3.3',
+    ],
 )
 
 BUILD_DIR = 'build'
@@ -32,11 +43,11 @@ def start_server():
         os.makedirs(BUILD_DIR)
 
     if not path(BUILD_DIR + '/neo4j-server.tar.gz').access(os.R_OK):
-        print "Downloading Neo4j Server"
-        urllib.urlretrieve ("http://download.neo4j.org/artifact?edition=community&version=%s&distribution=tarball" % NEO4J_VERSION, BUILD_DIR + "/neo4j-server.tar.gz")
+        print("Downloading Neo4j Server")
+        urlretrieve ("http://download.neo4j.org/artifact?edition=community&version=%s&distribution=tarball" % NEO4J_VERSION, BUILD_DIR + "/neo4j-server.tar.gz")
 
     if not path(BUILD_DIR + '/neo4j-server').access(os.R_OK):
-        print "Unzipping Neo4j Server.."
+        print("Unzipping Neo4j Server..")
         tar = tarfile.open(BUILD_DIR + "/neo4j-server.tar.gz")
         tar.extractall(BUILD_DIR)
         tar.close()
